@@ -310,8 +310,6 @@ class ResultWriter(Thread):
         
         try:
             request = p['request']
-            if request.offline:
-                return True
             ret = p['async'].get()
             response = request.response_class(request.response_queue, 'SUCCESS', ret)
             error = False
@@ -327,8 +325,9 @@ class ResultWriter(Thread):
             return
         try:
             pipe = self.redis.pipeline(transaction=True)
-            pipe.lpush(request.response_queue, response.serialize_resp())
-            pipe.expire(request.response_queue, request.timeout)
+            if not request.offline:
+                pipe.lpush(request.response_queue, response.serialize_resp())
+                pipe.expire(request.response_queue, request.timeout)
             if error:
                 pipe.lpush(self.command.failed_queue, response.serialize_failed_resp(request))
             else:
